//
//  TileView.swift
//  Dragrot
//
//  Created by Mark Meretzky on 12/14/14.
//  Copyright (c) 2014 Mark Meretzky. All rights reserved.
//

import UIKit

class TileView: UIImageView {
	var centerAtStartOfPan: CGPoint = CGPointZero;
	var rotate: CGAffineTransform = CGAffineTransformIdentity;

	required init(filename: String, x: CGFloat, y: CGFloat) {
		super.init(image: UIImage(named: filename)!);
		center = CGPointMake(x, y);
		userInteractionEnabled = true;
		
		//"Pan" means "drag".
		let panGestureRecognizer: UIPanGestureRecognizer =
			UIPanGestureRecognizer(target: self, action: "pan:");
		
		panGestureRecognizer.minimumNumberOfTouches = 1;
		panGestureRecognizer.maximumNumberOfTouches = 1;
		addGestureRecognizer(panGestureRecognizer);
		
		let rotationGestureRecognizer: UIRotationGestureRecognizer =
			UIRotationGestureRecognizer(target: self, action: "rotate:");
		addGestureRecognizer(rotationGestureRecognizer);
	}

	//never called
	required init(coder aDecoder: NSCoder) {
		super.init(coder: aDecoder);
	}

	//Called when a pan gesture has been detected.

	func pan(panGestureRecognizer: UIPanGestureRecognizer) {
		superview!.bringSubviewToFront(self);	//Put me on top.

		let d: CGPoint = panGestureRecognizer.translationInView(superview!);
		if panGestureRecognizer.state == UIGestureRecognizerState.Began {
			//Record the location of the start of this pan.
			centerAtStartOfPan = CGPointMake(center.x + d.x, center.y + d.y);
		}
		center = CGPointMake(centerAtStartOfPan.x + d.x, centerAtStartOfPan.y + d.y);
	}

	//Called when a rotation gesture has been detected.

	func rotate(rotationGestureRecognizer: UIRotationGestureRecognizer) {
		superview!.bringSubviewToFront(self);	//Put me on top.
		transform = CGAffineTransformMakeRotation(rotationGestureRecognizer.rotation);
	}

	/*
	// Only override drawRect: if you perform custom drawing.
	// An empty implementation adversely affects performance during animation.
	override func drawRect(rect: CGRect) {
		// Drawing code
	}
	*/

}
